summaryrefslogtreecommitdiffstats
path: root/src/main.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/main.rs')
-rw-r--r--src/main.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/main.rs b/src/main.rs
index 826e0f3..f33f4c7 100644
--- a/src/main.rs
+++ b/src/main.rs
@@ -94,8 +94,8 @@ struct Options {
#[structopt(long = "disable-ext-tabline")]
disable_ext_tabline: bool,
/// Enables dark theme
#[structopt(long = "prefer-dark-theme")]
prefer_dark_theme: bool,
/// Geometry of the window in widthxheight form
@@ -233,7 +233,7 @@ fn main() {
"gtk-application-prefer-dark-theme",
&true.to_value(),
) {
- error!("Failed to set dark theme setting: {}", err);
+ error!("Failed to set gtk-application-prefer-dark-theme setting: {}", err);
}
}
}
@@ -94,8 +94,8 @@ struct Options {
#[structopt(long = "disable-ext-tabline")]
disable_ext_tabline: bool,
- /// Enables dark theme
- #[structopt(long = "prefer-dark-theme")]
+ /// Instruct GTK to prefer dark theme
+ #[structopt(long = "gtk-prefer-dark-theme")]
prefer_dark_theme: bool,
/// Geometry of the window in widthxheight form